==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesJbo.php <==
<?php
/** Lojban (Lojban)
 *
 * @ingroup Language
 * @file
 *
 * @author Malafaya
 * @author OldakQuill
 */

$messages = array(
# User preference toggles
'tog-justify' => 'jufmei co mulno selkuspe',

# Dates
'sunday'        => 'la zedjed.',
'monday'        => 'la padjed.',
'tuesday'       => 'la redjed.',
'wednesday'     => 'la cedjed.',
'thursday'      => 'la vodjed.',
'friday'        => 'la mudjed.',
'saturday'      => 'la xadjed.',
'january'       => 'la pamast.',
'february'      => 'la remast.',
'march'         => 'la cimast.',
'april'         => 'la vomast.',
'june'          => 'la xamast.',
'july'          => 'la zemast.',
'august'        => 'la bimast.',
'september'     => 'la somast.',
'october'       => 'la daumast.',
'november'      => 'la feimast.',
'december'      => 'la gaimast.',
'january-gen'   => 'la pamast.',
'february-gen'  => 'la remast.',
'march-gen'     => 'la cimast.',
'april-gen'     => 'la vomast.',
'may-gen'       => 'la mumast.',
'june-gen'      => 'la xamast.',
'july-gen'      => 'la zemast.',
'august-gen'    => 'la bimast.',
'september-gen' => 'la somast.',
'october-gen'   => 'la daumast.',
'november-gen'  => 'la feimast.',
'december-gen'  => 'la gaimast.',
'may'           => 'la mumast.',

# Bits of text used by many pages
'categories'     => 'klesi',
'pagecategories' => '{{PLURAL:$1|klesi|klesi}}',

'qbedit'        => 'stika',
'qbpageoptions' => 'ti ckupau',
'mytalk'        => 'casnu mi',

'errorpagetitle'   => 'fliba',
'help'             => 'sidju ckupau',
'search'           => 'sisku',
'searchbutton'     => 'sisku',
'searcharticle'    => 'jarco',
'history_short'    => 'galfi plivei',
'printableversion' => 'plepri simsa',
'permalink'        => "vitno terjo'e",
'edit'             => 'stika',
'delete'           => 'daspo',
'protect'          => 'bandu',
'talkpagelinktext' => 'casnu',
'specialpage'      => 'steci ckupau',
'talk'             => 'casnu',
'toolbox'          => 'tutci',
'otherlanguages'   => 'drata bangu',
'lastmodifiedat'   => "le vi ckupau rore'u se galfi de'i li $2 $1", # $1 date, $2 time
'jumptosearch'     => 'sisku',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'copyright'         => "lo selvau cu gubni ja'i la'o gy. $1 .gy.",
'currentevents'     => 'nuzba ckupau',
'currentevents-url' => 'Project:nuzba ckupau',
'disclaimers'       => "xusra lo za'i na fuzme",
'mainpage'          => 'ralju ckupau',
'portal'            => 'bende ckupau',
'portal-url'        => 'Project:bende ckupau',
'privacy'           => "javni be sera'a lo sivni",
'sitesupport'       => 'jdini sidju',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-mediawiki' => 'notci',
'nstab-category'  => 'klesi',

# Login and logout pages
'login'          => "co'a se jaspu",
'logout'         => "co'u se jaspu",
'userlogout'     => "co'u se jaspu",
'gotaccountlink' => "co'a se jaspu",

# Edit pages
'minoredit'      => "ti nu na'evajni galfi",
'watchthis'      => 'zgana ti',
'savearticle'    => 'vreji le ckupau',
'showpreview'    => 'troci jarco',
'showdiff'       => 'jarco lo te frica',
'loginreqlink'   => "co'a se jaspu",
'editing'        => "ca galfi la'e lu $1 li'u",
'editingsection' => 'ca galfi le selcmene be zoi $1 (section)',
'editingcomment' => 'ca galfi le selcmene be zoi $1 (comment)',

# Search results
'searchresults' => "tu'a le se sisku",

# Preferences page
'textboxsize'       => 'ca galfi',
'searchresultshead' => "tu'a le se sisku",

# Recent changes
'recentchanges'     => 'puzi nunstika',
'recentchangestext' => 'liste loi nu puzi galfi la .uikis.',
'diff'              => 'te frica',
'hist'              => 'galfi plivei',

# Recent changes linked
'recentchangeslinked' => "srana nunga'i",

# Upload
'upload'    => 'benji lo datnyvei',
'uploadbtn' => 'benji lo datnyvei',

# Random page
'randompage' => 'cunso ckupau',

# Miscellaneous special pages
'specialpages' => 'steci ckupau',
'move'         => 'stika lo cmene',

# Special:Allpages
'allarticles' => 'ro notci',

# Watchlist
'watch'         => 'zgana',
'watchthispage' => 'zgana ti',

# Delete/protect/revert
'deletedarticle' => "pu daspo la'e lu [[$1]] li'u",
'dellogpage'     => 'plivei fi loi nu daspo',
'deletionlog'    => 'plivei fi loi nu daspo',

# Restrictions (nouns)
'restriction-edit' => 'stika',

# Contributions
'contributions' => 'selstika le pilno',
'mycontris'     => 'pu selstika mi',

'sp-contributions-submit' => 'sisku',

# What links here
'whatlinkshere' => 'ma jorne ti',

# Block/unblock
'blocklink' => 'zunti',

# Move page
'movedto'   => 'te muvdu',
'1movedto2' => "le pu se cmene lu [[$1]] li'u cu ca se cmene lu [[$2]] li'u",

# Tooltip help for the actions
'tooltip-pt-logout' => "co'u se jaspu",

# Special:Filepath
'filepath-page' => 'se datnyvei zoi',

);

==> mediawiki-1.13.5.tbz: www/mediawiki/languages/messages/MessagesJbo.php <==
<?php
/** Lojban (Lojban)
 *
 * @ingroup Language
 * @file
 *
 * @author Homo logos
 * @author Malafaya
 * @author OldakQuill
 */

$messages = array(
# User preference toggles
'tog-justify' => 'jufmei co mulno selkuspe',

# Dates
'sunday'        => 'la zedjed.',
'monday'        => 'la padjed.',
'tuesday'       => 'la redjed.',
'wednesday'     => 'la cedjed.',
'thursday'      => 'la vodjed.',
'friday'        => 'la mudjed.',
'saturday'      => 'la xadjed.',
'january'       => 'la pamast.',
'february'      => 'la remast.',
'march'         => 'la cimast.',
'april'         => 'la vomast.',
'june'          => 'la xamast.',
'july'          => 'la zemast.',
'august'        => 'la bimast.',
'september'     => 'la somast.',
'october'       => 'la daumast.',
'november'      => 'la feimast.',
'december'      => 'la gaimast.',
'january-gen'   => 'la pamast.',
'february-gen'  => 'la remast.',
'march-gen'     => 'la cimast.',
'april-gen'     => 'la vomast.',
'may-gen'       => 'la mumast.',
'june-gen'      => 'la xamast.',
'july-gen'      => 'la zemast.',
'august-gen'    => 'la bimast.',
'september-gen' => 'la somast.',
'october-gen'   => 'la daumast.',
'november-gen'  => 'la feimast.',
'december-gen'  => 'la gaimast.',
'may'           => 'la mumast.',

# Categories related messages
'pagecategories'  => '{{PLURAL:$1|klesi|klesi}}',
'category_header' => 'fe le kibypapri cu klesi "$1"',
'subcategories'   => "le'a ti",

'qbedit'        => 'stika',
'qbpageoptions' => 'ti ckupau',
'mytalk'        => 'casnu mi',

'errorpagetitle'   => 'fliba',
'help'             => 'sidju ckupau',
'search'           => 'sisku',
'searchbutton'     => 'sisku',
'searcharticle'    => 'jarco',
'history_short'    => 'galfi plivei',
'printableversion' => 'plepri simsa',
'permalink'        => "vitno terjo'e",
'edit'             => 'stika',
'delete'           => 'daspo',
'protect'          => 'bandu',
'talkpagelinktext' => 'casnu',
'specialpage'      => 'steci ckupau',
'talk'             => 'casnu',
'toolbox'          => 'tutci',
'otherlanguages'   => 'drata bangu',
'lastmodifiedat'   => "le vi ckupau rore'u se galfi de'i li $2 $1", # $1 date, $2 time
'jumptosearch'     => 'sisku',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'copyright'            => "lo selvau cu gubni ja'i la'o gy. $1 .gy.",
'currentevents'        => 'nuzba ckupau',
'currentevents-url'    => 'Project:nuzba ckupau',
'disclaimers'          => "xusra lo za'i na fuzme",
'mainpage'             => 'ralju ckupau',
'mainpage-description' => 'ralju ckupau',
'portal'               => 'bende ckupau',
'portal-url'           => 'Project:bende ckupau',
'privacy'              => "javni be sera'a lo sivni",

'editsection'          => 'stika ti',
'editsection-brackets' => '[$1]',
'editold'              => 'edit',
'viewsourceold'        => 'catlu le mifra',
'editsectionhint'      => 'stika ti: $1',
'toc'                  => 'ckupau pakbu',
'showtoc'              => 'jarco',
'hidetoc'              => 'toljarco',
'thisisdeleted'        => 'View or restore $1?',
'viewdeleted'          => 'View $1?',
'restorelink'          => '{{PLURAL:$1|one deleted edit|$1 deleted edits}}',
'feedlinks'            => 'Feed:',
'feed-invalid'         => 'Invalid subscription feed type.',
'feed-unavailable'     => 'Syndication feeds are not available',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-mediawiki' => 'notci',
'nstab-category'  => 'klesi',

# Login and logout pages
'login'          => "co'a se jaspu",
'logout'         => "co'u se jaspu",
'userlogout'     => "co'u se jaspu",
'gotaccountlink' => "co'a se jaspu",

# Edit pages
'minoredit'      => "ti nu na'evajni galfi",
'watchthis'      => 'zgana ti',
'savearticle'    => 'vreji le ckupau',
'showpreview'    => 'troci jarco',
'showdiff'       => 'jarco lo te frica',
'loginreqlink'   => "co'a se jaspu",
'editing'        => "ca galfi la'e lu $1 li'u",
'editingsection' => 'ca galfi le selcmene be zoi $1 (section)',
'editingcomment' => 'ca galfi le selcmene be zoi $1 (comment)',

# History pages
'last'       => "prula'i",
'page_first' => 'pamoi',
'page_last'  => 'fanmo',

# Search results
'searchresults' => "tu'a le se sisku",

# Preferences page
'textboxsize'       => 'ca galfi',
'searchresultshead' => "tu'a le se sisku",

# Recent changes
'recentchanges'     => 'puzi nunstika',
'recentchangestext' => 'liste loi nu puzi galfi la .uikis.',
'diff'              => 'te frica',
'hist'              => 'galfi plivei',

# Recent changes linked
'recentchangeslinked' => "srana nunga'i",

# Upload
'upload'    => 'benji lo datnyvei',
'uploadbtn' => 'benji lo datnyvei',

# Random page
'randompage' => 'cunso ckupau',

# Miscellaneous special pages
'move' => 'stika lo cmene',

# Special:AllPages
'allarticles' => 'ro notci',

# Special:Categories
'categories' => 'klesi',

# Watchlist
'watch'         => 'zgana',
'watchthispage' => 'zgana ti',

# Delete/protect/revert
'deletedarticle' => "pu daspo la'e lu [[$1]] li'u",
'dellogpage'     => 'plivei fi loi nu daspo',
'deletionlog'    => 'plivei fi loi nu daspo',

# Restrictions (nouns)
'restriction-edit' => 'stika',

# Contributions
'contributions' => 'selstika le pilno',
'mycontris'     => 'pu selstika mi',

'sp-contributions-submit' => 'sisku',

# What links here
'whatlinkshere' => 'ma jorne ti',

# Block/unblock
'blocklink'    => 'zunti',
'contribslink' => 'selstika',

# Move page
'movedto'   => 'te muvdu',
'1movedto2' => "le pu se cmene lu [[$1]] li'u cu ca se cmene lu [[$2]] li'u",

# Tooltip help for the actions
'tooltip-pt-logout'             => "co'u se jaspu",
'tooltip-n-mainpage'            => 'vitke le ralju ckupau',
'tooltip-n-randompage'          => 'jarco lo cunso ckupau',
'tooltip-n-help'                => 'sidju kibypapri',
'tooltip-t-whatlinkshere'       => "nu liste lo zifyga'ikibjudri poi ke'a kibjorne le vi ckupau",
'tooltip-t-recentchangeslinked' => "lo puzi nunga'i pe lo kibypapri poi kibjorne le vi ckupau",

# Special:FilePath
'filepath-page' => 'se datnyvei zoi',

# Special:SpecialPages
'specialpages' => 'steci ckupau',

);
